@@ -16,11 +16,12 @@
 import re
 import logging
 import qsAPI
+from .systemrule import *
 
 
 def extract_mail(u):
     """Extract the mail attribute from the user dictionary"""
-    logging.debug("Extract mail from user %s" % str(u))
+    logging.debug(f"Extract mail from user {u}")
     if not u:
         logging.error("User is empty")
         return None
@@ -41,7 +42,7 @@ def extract_mail(u):
 def find_mail_from_user_id(qrs, id):
     users = qrs.UserGet(pFilter="id eq %s" % id)
     if len(users) != 1:
-        logging.error("Cannot find a user with ID=%" % id)
+        logging.error(f"Cannot find a user with ID={id}")
         mail = None
     else:
         mail = extract_mail(users[0])
@@ -50,7 +51,7 @@ def find_mail_from_user_id(qrs, id):
 
 def delete_removed_exernally_users(qrs, user_directory, dryrun=True):
     users = qrs.UserGet(
-        pFilter="userDirectory eq '%s' and removedExternally eq True" % user_directory
+        pFilter=f"userDirectory eq '{user_directory}' and removedExternally eq True"
     )
     logging.warning("Users to be deleted: %s" % len(users))
     for u in users:
@@ -59,30 +60,55 @@ def delete_removed_exernally_users(qrs, user_directory, dryrun=True):
             qrs.UserDelete(u["id"])
 
 
-def export_users_and_groups(
-    qrs,
-    pFilter="removedExternally ne True",
-    pUserID="full",
-    groupFilter="^QLIKSENSE_",
-    userAttribute="name",
-    sep="\t",
-):
-    users = qrs.UserGet(pFilter=pFilter, pUserID=pUserID)
-    for u in users:
-        if "attributes" in u.keys():
-            for a in u["attributes"]:
-                groupname = a["attributeValue"]
-                if re.match(groupFilter, groupname, re.IGNORECASE):
-                    print(
-                        "{name}{sep}{groupname}\n".format(
-                            name=u[userAttribute], groupname=groupname, sep=sep
-                        )
-                    )
+def extract_user_groups(user, groupFilter="^QLIKSENSE_"):
+    if "attributes" in user.keys():
+        for a in user["attributes"]:
+            groupname = a["attributeValue"]
+            if re.match(groupFilter, groupname, re.IGNORECASE):
+                yield (grouname)
+
+
+def user_info(qrs, user_id, resources, access):
+    users = qrs.UserGet(pFilter=f"userId eq '{user_id}'")
+    logging.debug(users)
+    if len(users) == 0:
+        logging.warning(f"UserId {userid} not found!")
+        yield {"Missing userId": userid}
+        return
+
+    user = users[0]
+
+    ## user info
+
+    for field in [
+        "name",
+        "createdDate",
+        "inactive",
+        "removedExternally",
+        "blacklisted",
+        "deleteProhibited",
+        "roles",
+    ]:
+        yield {field: user[field]}
+
+    ## License
+
+    param = {"filter": f"user.userId eq '{user_id}'"}
+    for typ in ["analyzer", "professional"]:
+        lic = qrs.driver.get(f"/qrs/license/{typ}accesstype/count", param=param).json()
+        yield {f"{typ} license": True if lic["value"] == 1 else False}
+
+    # access to resources
+    iduser = user["id"]
+    for resource in resources:
+        resp = accessible_objects(qrs, resource, iduser, access)
+        result = list(map(lambda r: r["name"], resp))
+        yield {f"{resource} {access} access": result}
 
 
 def user_sessions(hosts, certificate, usergroup, userid, vproxies=""):
     for server in hosts.split(","):
         for vproxy in vproxies.split(","):
             qps = qsAPI.QPS(proxy=server, certificate=certificate)
-            print(server + " : " + vproxy)
+            print(f"{server}  : {vproxy}")
             print(qps.GetUser(usergroup, user).json())
